BUTTONS=(
    "LEFT",
    "RIGHT",
    "UP",
    "DOWN",
    "RED",
    "GREEN",
    "YELLOW",
    "BLUE",
    "CHANNELUP",
    "CHANNELDOWN",
    "VOLUMEUP",
    "VOLUMEDOWN",
    "PLAY",
    "PAUSE",
    "STOP",
    "REWIND",
    "FASTFORWARD",
    "ASTERISK",
    "BACK",
    "EXIT",
    "ENTER",
    "AMAZON",
    "NETFLIX",
    "3D_MODE",
    "AD",                   # Audio Description toggle
    "ADVANCE_SETTING",
    "ALEXA",                # Amazon Alexa
    "AMAZON",               # Amazon Prime Video app
    "ASPECT_RATIO",         # Quick Settings Menu - Aspect Ratio
    "CC",                   # Closed Captions
    "DASH",                 # Live TV
    "EMANUAL",              # User Guide
    "EZPIC",                # Pictore mode preset panel
    "EZ_ADJUST",            # EzAdjust Service Menu
    "EYE_Q",                # Energy saving panel
    "GUIDE",
    "HCEC",                 # SIMPLINK toggle
    "HOME",                 # Home Dashboard
    "INFO",                 # Info button
    "IN_START",             # InStart Service Menu
    "INPUT_HUB",            # Home Dashboard
    "IVI",
    "LIST",                 # Live TV
    "LIVE_ZOOM",            # Live Zoom
    "MAGNIFIER_ZOOM",       # Focus Zoom
    "MENU",                 # Quick Settings Menu
    "MUTE",
    "MYAPPS",               # Home Dashboard
    "NETFLIX",              # Netflix app
    "POWER",                # Power button
    "PROGRAM",              # TV Guide
    "QMENU",                # Quick Settings Menu
    "RECENT",               # Home Dashboard - Recent Apps or last app
    "RECLIST",              # Recording list
    "RECORD",
    "SAP",                  # Multi Audio Setting
    "SCREEN_REMOTE",        # More Actions panel
    "SEARCH",
    "SOCCER",               # Sport preset
    "TELETEXT",
    "TEXTOPTION",
    "TIMER",                # Sleep Timer panel
    "TV",
    "TWIN",                 # Twin View
    "UPDOWN",               # Always Ready app
    "USP",                  # Movie, TVshow, app list
    "YANDEX",
    "0",
    "1",
    "2",
    "3",
    "4",
    "5",
    "6",
    "7",
    "8",
    "9"
)
